@@ -17,13 +17,16 @@ get '/' => sub ($c) {
   # get a specs config file for the synth model
   my $set = './eg/' . $synth->model . '.set';
   my $specs = -e $set ? do $set : undef;
+  # get the known groups if there are specs
   my $groups = $specs ? $specs->{group} : undef;
   $groups = [ sort @$groups ] if $groups;
+  my $settings = $synth->search_settings(group => $group);
   $c->render(
     template => 'index',
     model    => $model,
     group    => $group,
     groups   => $groups,
+    settings => $settings,
   );
 } => 'index';
 
@@ -36,13 +39,24 @@ __DATA__
 <form action="<%= url_for('index') %>" method="get">
   <label for="model">Model:</label>
   <input name="model" id="model" value="<%= $model %>">
-  <label for="group">Modual:</label>
+  <label for="group">Module:</label>
   <select name="group" id="group">
 % for my $g (@$groups) {
     <option value="<%= $g %>" <%= $g eq $group ? 'selected' : '' %>><%= ucfirst $g %></option>
 % }
   </select>
+  <input type="submit" value="Submit">
 </form>
+<p></p>
+% for my $s (@$settings) {
+%   my $setting = (values(%$s))[0];
+%   if ($setting->{bottom} && $setting->{top}) {
+<b>Param</b>: <i><%= $setting->{parameter} %></i> <%= $setting->{control} %> (<%= $setting->{bottom} %>-<%= $setting->{top} %>),
+<b>Value</b>: <%= $setting->{value} %> <%= $setting->{unit} %>,
+<b>Default</b>: <%= $setting->{is_default} %>
+%   }
+<br>
+% }
 
 @@ layouts/default.html.ep
 <!DOCTYPE html>
