@@ -3,7 +3,7 @@ our $AUTHORITY = 'cpan:GENE';
 
 # ABSTRACT: Synthesizer settings librarian
 
-our $VERSION = '0.0012';
+our $VERSION = '0.0013';
 
 use Moo;
 use strictures 2;
@@ -118,8 +118,10 @@ sub search_settings {
   my ($self, %args) = @_;
   my @where;
   for my $arg (keys %args) {
+    next unless $args{$arg};
     push @where, q/json_extract(settings, '$./ . $arg . q/') = / . "'$args{$arg}'";
   }
+  return [] unless @where;
   my $sql = 'select id,settings from ' . $self->model . ' where ' . join(' and ', @where);
   my $results = $self->_sqlite->query($sql);
   my @settings;
@@ -174,7 +176,7 @@ Synth::Config - Synthesizer settings librarian
 
 =head1 VERSION
 
-version 0.0012
+version 0.0013
 
 =head1 SYNOPSIS
 
